{ config, pkgs, ... }:

let hostname = "gAluminum";
in {
  imports = [ ./hardware.nix ./wireguard.nix ];

  boot = {
    supportedFilesystems = [ "ntfs" ];
    loader = {
      efi.canTouchEfiVariables = true;
      efi.efiSysMountPoint = "/boot/efi";
      systemd-boot.enable = true;
    };

    initrd.luks.devices = {
      root = {
        device = "/dev/disk/by-uuid/c2bac3a6-0999-4e1d-a676-bf4bcafee2d4";
        preLVM = true;
        allowDiscards = true;
      };
    };
  };

  networking = {
    hostName = hostname;
    networkmanager.wifi = {
      powersave = false;
      macAddress = "random";
    };
  };

  time.timeZone = "Europe/London";
  virtualisation.virtualbox.host.enable = true;
  virtualisation.virtualbox.host.enableExtensionPack = true;
  users.extraGroups.vboxusers.members = [ "giulio" ];

  services.printing.enable = true;
  sound.enable = true;

  hardware = {
    pulseaudio.enable = true;
    ledger.enable = true;
  };

  services.teamviewer.enable = true;
  programs.steam.enable = true;
  environment.systemPackages = with pkgs; [ efibootmgr ];
  system.stateVersion = "21.05"; # Did you read the comment?
}
